pub struct FlowStepResubmitMessage {
pub account: ObjectDescription,
pub duplicate_message: Bool,
pub flow_selector: String,
pub header_name: String,
pub header_value: String,
pub source: ObjectDescription,
}Fields
account: ObjectDescriptionAccount to submit the message to.
duplicate_message: Boolflow_selector: StringSelector of the flow to submit the message to.
header_name: StringName of the header to add to the email.
header_value: StringValue to set in the header.
source: ObjectDescriptionSource to submit the message to.